# CAVASS

CAVASS python APIs.

## Usage

from cavass.ops import *

Note that running cavass commands requires the following shell environment configs: PATH including CAVASS build path and VIEWNIX_ENV.
If the shell does not include these configs by default, set cavasspy.ops.CAVASS_PROFILE_PATH to your CAVASS build path (default path is ~/cavass-build in installation if you didn't make any change) before performing CAVASS commands.

